from {{cookiecutter.package_name}}.architecture.feature import (
    Feature, FeatureBatch
)
from {{cookiecutter.package_name}}.architecture.prediction import (
    Prediction, PredictionBatch
)
from {{cookiecutter.package_name}}.architecture.model import Model
